@@ -1970,7 +1970,7 @@ class SETDataReader:
         )
         return stmt
 
-    @lru_cache
+    @lru_cache(maxsize=128)
     def _d_trade_subquery(self):
         daily_stock_stat_t = self._table("DAILY_STOCK_STAT")
         return (
@@ -2429,7 +2429,7 @@ class SETDataReader:
     Custom business day functions
     """
 
-    @lru_cache
+    @lru_cache(maxsize=128)
     def _get_holidays(self) -> List[pd.Timestamp]:
         tds = self.get_trading_dates()
         return (
@@ -2456,7 +2456,7 @@ class SETDataReader:
         return df
 
 
-@lru_cache
+@lru_cache(maxsize=128)
 def _SETDataReaderCached() -> SETDataReader:
     out: SETDataReader = utils.wrap_cache_class(SETDataReader)()  # type: ignore
 
